rdbms

package
v0.54.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TIMEOUT_PING = time.Second * 1
)

Variables

This section is empty.

Functions

func ConnectDB

func ConnectDB(cfg *config.Config, dbPosition int) (*pgxpool.Pool, error)

ConnectDB configures and creates a Postgres connection pool.

func Credentials

func Credentials(db config.Rdb) (string, error)

Credentials conveniently assembles a string for the Postgres client.

func WhichDB

func WhichDB(cfg *config.Config, dbPosition int) config.Rdb

WhichDB reads from a list of databases in the Config struct. A developer must select an index in that array.

Types

This section is empty.

Jump to